==> redshift-jquery-2.0.0.tgz: package/src/plugin.js <==
/*
    Redshift jQuery plugin
*/
"use strict";

var _jQuery, // Private instance of jQuery
    _redshift, // Private instance of Redshift

    ACTION = 'redshiftAction', // Data key for Action
    
    
    /*
        Generate a plugin function
        
        @param [string]: Method name to attach to jQuery and to call on Action
    */
    generateFunction = function (method) {
        _jQuery.fn[method] = function () {
            execute(this, arguments, method);
            return this;
        }
    },


    /*
        Get or create Action on jQuery element
        
        @param [jQuery selection]
        @return [Action]
    */
    getAction = function ($element) {
        var action = $element.data(ACTION);
        
        // If Action doesn't exist yet, create it
        if (!action) {
            // Create Action
            action = _redshift.newAction();
            
            // Change Action scope to jQuery element
            action.setProp('scope', $element);
            
            // Bind Action to jQuery element
            $element.data(ACTION, action);
        }
        
        return action;
    },


    /*
        Execute defined function
    */
    execute = function ($elements, args) {
        var argsLength = args.length,
            params = [],
            returnVal = [],
            methodIsNamed = (arguments.length === 3),
            method = methodIsNamed ? arguments[2] : args[0],
            argsIndex = methodIsNamed ? 0 : 1;

        // Build argument array
        for (var i = argsIndex; i < argsLength; i++) {
            params.push(args[i]);
        }

        // Loop through elements and fire each Action with arguments
        $elements.each(function () {
            var action = getAction($(this)),
                output = action[method].apply(action, params),
                thisReturn = (output == action) ? $(this) : output;
            
            returnVal.push(thisReturn);
        });
        
        // Return all elements if no return value, else return final value
        return (returnVal.length === 1) ? returnVal[0] : returnVal;
    };

module.exports = {
    
    /*
        Load Redshift jQuery plugin
        
        @param [jQuery]
        @param [Redshift]
    */
    load: function (JQ, RS) {
        _jQuery = JQ;
        _redshift = RS;
        
        /*
            Action plugin
            
            Usage
                $('.selector').action(); // Return the Action associated with this selector
                $('.selector').action('setProp', 'foo', 'bar'); // Call Action.setProp('foo', 'bar')
            
            @param [string]: Action function to call
            @param [...]: Subsequent arguments
            @return [jQuery || Action]
        */
        _jQuery.fn.action = function () {
            var returnVal;

            if (arguments.length) {
                returnVal = execute(this, arguments);
                
                if (returnVal === Action) {
                    returnVal = this;
                }
            } else {
                returnVal = getAction($(this));
            }
            
            return returnVal;
        };
        
        /*
            Main Action method plugins
            
            Usage
                $('.selector').play('yourPreset', { foo: bar });
        */
        generateFunction('play');
        generateFunction('track');
        generateFunction('run');
    }
};

==> redshift-jquery-3.0.0.tgz: package/src/plugin.js <==
/*
    Redshift jQuery plugin
*/
"use strict";

var _jQuery, // Private instance of jQuery
    _redshift, // Private instance of Redshift

    ACTION = 'redshiftAction', // Data key for Action
    
    
    /*
        Generate a plugin function
        
        @param [string]: Method name to attach to jQuery and to call on Action
    */
    generateFunction = function (method) {
        _jQuery.fn[method] = function () {
            execute(this, arguments, method);
            return this;
        }
    },


    /*
        Get or create Action on jQuery element
        
        @param [jQuery selection]
        @return [Action]
    */
    getAction = function ($element) {
        var action = $element.data(ACTION);
        
        // If Action doesn't exist yet, create it
        if (!action) {
            // Create Action
            action = _redshift.newAction();
            
            // Change Action scope to jQuery element and add dom
            action
                .setProp('scope', $element)
                .setProp('dom', $element[0]);
            
            // Bind Action to jQuery element
            $element.data(ACTION, action);
        }
        
        return action;
    },


    /*
        Execute defined function
    */
    execute = function ($elements, args) {
        var argsLength = args.length,
            params = [],
            returnVal = [],
            methodIsNamed = (arguments.length === 3),
            method = methodIsNamed ? arguments[2] : args[0],
            argsIndex = methodIsNamed ? 0 : 1;

        // Build argument array
        for (var i = argsIndex; i < argsLength; i++) {
            params.push(args[i]);
        }

        // Loop through elements and fire each Action with arguments
        $elements.each(function () {
            var action = getAction($(this)),
                output = action[method].apply(action, params),
                thisReturn = (output == action) ? $(this) : output;
            
            returnVal.push(thisReturn);
        });
        
        // Return all elements if no return value, else return final value
        return (returnVal.length === 1) ? returnVal[0] : returnVal;
    };

module.exports = {
    
    /*
        Load Redshift jQuery plugin
        
        @param [jQuery]
        @param [Redshift]
    */
    load: function (JQ, RS) {
        _jQuery = JQ;
        _redshift = RS;
        
        /*
            Action plugin
            
            Usage
                $('.selector').action(); // Return the Action associated with this selector
                $('.selector').action('setProp', 'foo', 'bar'); // Call Action.setProp('foo', 'bar')
            
            @param [string]: Action function to call
            @param [...]: Subsequent arguments
            @return [jQuery || Action]
        */
        _jQuery.fn.action = function () {
            var returnVal;

            if (arguments.length) {
                returnVal = execute(this, arguments);
                
                if (returnVal === Action) {
                    returnVal = this;
                }
            } else {
                returnVal = getAction($(this));
            }
            
            return returnVal;
        };
        
        /*
            Main Action method plugins
            
            Usage
                $('.selector').play('yourPreset', { foo: bar });
        */
        generateFunction('play');
        generateFunction('track');
        generateFunction('run');
    }
};
